/*
 * Project name:
       Motion Click
 * Copyright:
      (c) mikroElektronika, 2015.
 * Revision History:
      20140826:
      - Initial release (RD);
 * Description:
      Motion click is a simple solution for adding an infrared motion detectorsensitive only to live bodiesto your design. 
      It carries a D203B Pyroelectric motion sensor connected to a BISS0001 infrared sensor controller IC. 
      Onboard potentiometer enables you to calibrate the sensor for distance. 
      The board also features a photo resistor that enables you to set the sensor to work only at night. 
      Motion click communicates with the target board through mikroBUS IN (out) and RST lines.

      Motion click is ideal for alarm systems, light switch controllers, and similar systems where human presence needs to be detected.
      The pyroelectric motion sensor generates a voltage when exposed to infrared radiation emitted by live bodies 
      (the white plastic Flesner lens covering the sensor filters visible light). 
      The BISS001 IC processes the signal and sends an interrupt to the MCU. 
      To set up the detecting range of the sensor (up to 4 meters), use the onboard potentiometer. 
      You can also activate and deactivate the sensor through the mikroBUS RST pin.

      You can set up motion click to be operational only in darkness by activating the onboard Photo resistor. 
      All you have to do is resolder the zero-ohm jumper just below the photo resistor on the left side of the click board.
      
      Motion click is a motion detector sensitive only to live bodies. 
      It carries D203B, a pyroelectric sensor which generates a voltage when exposed to infrared light. 
      The signal is processed by a BIS0001 PIR sensor controller which sends an interrupt to the MCU through 
      the mikroBUS IN (out) line. An onboard potentiometer lets you adjust the detecting range of the sensor. 
      Motion click also has a night only moderesoldering a zero-ohm jumper activates the onboard photo resistor which acts 
      as a light-sensitive switch. You can also switch the sensor ON and OFF by sending a signal from the MCU through 
      the mikroBUS RST pin.
      
      It uses a 3.3V power supply!

 * Test configuration:
     MCU:             ATmega32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev. Board:      EasyAVR7
                      http://www.mikroe.com/easyavr/
     Oscillator:      Oscillator Frequency 8.0000 MHz, 8.0000 MHz Crystal
     ext. modules:    Motion Click
                      http://www.mikroe.com/click/motion/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
      - Place Motion Click board in the mikroBUS socket 1.
      - Turn On SW10.8 switch for PORTD LEDs.
      - Set development board J5 jumper according to 3.3V position!
      - Set development board J21 on PD4 for Buzzer.
*/

#include<built_in.h>

sbit Motion_Sens_EN at PINA.B1;

void Tone1() {
  Sound_Play(659, 250);        // Frequency = 659Hz, duration = 250ms
}

void Tone2() {
  Sound_Play(698, 250);        // Frequency = 698Hz, duration = 250ms
}

void Tone3() {
  Sound_Play(784, 250);        // Frequency = 784Hz, duration = 250ms
}

void main() {
  DDD2_bit = 0;
  Sound_Init(&PORTD,4);        // Initialize sound pin
   
  Motion_Sens_EN = 1;          // Enable Motion sensor

  while(1){
    if (PIND.B2){              // If sensor is activated
      Tone1();                 // Play tone
    }
  }
}